"""
__author__ = "Ashwinkumar Ajithkumar Pillai"
__date__ = 3/12/24
__version__ = "1.0"
__license__ = "MIT style license file"
"""

def getTimeSlotMapping() -> dict:

    """

    This function returns the time slot mapping.

    Period	       1 (MWF)	        2 (TR)	        Encoding - MWF	Encoding - TR
    ------         -------          ------          --------------  -------------

    1st period	   8:00 - 8:50	    8:00 - 9:15	    11	            21
    2nd period	   9:10 - 10:00	    9:35 - 10:50	12	            22
    3rd period	   10:20 - 11:10	11:10 - 12:25	13          	23
    4th period	   11:30 - 12:20	12:45 - 14:00	14          	24
    5th period	   12:40 - 13:30	14:20 - 15:35	15          	25
    6th period	   13:50 - 14:40	15:55 - 17:10	16          	26
    7th period	   15:00 - 15:50	17:30 - 18:45	17          	27
    8th period	   16:10 - 17:00	18:30 - 19:45	18	            28
    9th period	   17:20 - 18:10	20:00 - 21:15	19	            29
    10th period	   18:30 - 19:20	21:30 - 22:45	110	            210
    11th period	   18:50 - 19:40		            111	
    12th period	   19:55 - 20:45		            112	
    13th period	   21:00 - 21:50		            113	
    

    Arguments
    ----------
    
    Returned Values
    ----------
    time_slots : dict

    """

    timeSlots = {
        '800-850': '11',
        '910-1000': '12',
        '1020-1110': '13',
        '1130-1220': '14',
        '1240-1330': '15',
        '1350-1440': '16',
        '1500-1550': '17',
        '1610-1700': '18',
        '1720-1810': '19',
        '1830-1920': '110',
        '1850-1940': '111',
        '1955-2045': '112',
        '2100-2150': '113',
        '800-915': '21',
        '935-1050': '22',
        '1110-1225': '23',
        '1245-1400': '24',
        '1420-1535': '25',
        '1555-1710': '26',
        '1730-1845': '27',
        '1830-1945': '28',
        '2000-2115': '29',
        '2130-2245': '210',
        '1-2359': "Z500"}

    return timeSlots
